/*! isFrozenUA
    A freeze-test for your user-agent string
    https://github.com/faisalman/ua-is-frozen
    Author: Faisal Salman <f@faisalman.com>
    MIT License */
declare function isFrozenUA(ua: string): boolean;
export { isFrozenUA };
